---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**Expected behavior**
What you expected to happen (please include a reference to the DICOM standard
if relevant).

**Steps To Reproduce**
How to reproduce the issue. Please include a minimum working code sample, the
traceback (if any) and the anonymized DICOM dataset (if relevant).

**Your environment**
Please use the `pydicom.env_info` module (available in **pydicom 2 or later**)
to gather information about your environment and paste it into the issue:

```bash
$ python -m pydicom.env_info
```
